@@ -1,10 +1,10 @@
 import enum
 import os
-import sys
 import socket
-import re
+import stat
+import sys
 
-from mini_buildd import util, files
+from mini_buildd import files, util
 
 #: This should never ever be changed
 CHAR_ENCODING = "UTF-8"
@@ -21,7 +21,6 @@ MAX_HTTPD_THREADS = 100
 MAX_EVENTS_QUEUE_CLIENTS = 70
 
 #: HTTPD log file names
-LOG_FILE = "daemon.log"
 ACCESS_LOG_FILE = "access.log"
 
 #: (Debian package) path for the internal package templates
@@ -75,24 +74,12 @@ class Uri:
 
     DJANGO_PATH_REGEX = r"(?:(?P<path>.*))?"
 
-    def __init__(self, uri, auth=AUTH_NONE, with_index=False, cache_ttl=0, regex=None, django_with_path=False):
+    def __init__(self, uri, auth=AUTH_NONE, django_with_path=False):
         self.uri = uri
 
         #: Auth
         self.auth = auth
 
-        #: Enable directory listing
-        self.with_index = with_index
-
-        #: Browser cache TTL in seconds (0 for no cache)
-        self.cache_ttl = cache_ttl
-
-        #: Restrict access via regex
-        if regex is not None:
-            self.regex = re.compile(r"^" + self.join(regex))
-        else:
-            self.regex = regex
-
         #: Non-static: Add 'path' to django URI
         self.django_with_path = django_with_path
 
@@ -125,13 +112,8 @@ class Uri:
 #: 'dir': Directory Listing (django).
 #: 'static': Static delivery (twisted).
 URIS = {
-    # Note (cache_ttl=0): If browser cache should be enabled at some point, then here. However, we have no "hashed-on-change" support and it's confusing if
-    # 'though F5, js still running old code'. Also a real PITA in most browsers to clear the cache.
     "static": {
-        "static": Uri("/static/static/", cache_ttl=0),
-    },
-    "home": {
-        "view": Uri("/mini_buildd/"),
+        "static": Uri("/static/static/"),
     },
     "setup": {
         "view": Uri("/mini_buildd/setup/"),
@@ -139,17 +121,17 @@ URIS = {
     "events": {
         "view": Uri("/mini_buildd/events/", django_with_path=True),
         "dir": Uri("/mini_buildd/events-dir/", django_with_path=True),
-        "static": Uri("/static/events/", with_index=True),
+        "static": Uri("/static/events/"),
         "attach": Uri("/static/events.attach"),
     },
     "builds": {
         "dir": Uri("/mini_buildd/builds-dir/", django_with_path=True),
-        "static": Uri("/static/builds/", with_index=True),
+        "static": Uri("/static/builds/"),
     },
     "repositories": {
         "view": Uri("/mini_buildd/repositories/", django_with_path=True),
         "dir": Uri("/mini_buildd/repositories-dir/", django_with_path=True),
-        "static": Uri("/repositories/", with_index=True, regex=r"(?![^/]+/(conf/.*|db/.*))"),
+        "static": Uri("/repositories/"),
     },
     "builders": {
         "view": Uri("/mini_buildd/builders/"),
@@ -160,10 +142,6 @@ URIS = {
     "api": {
         "view": Uri("/mini_buildd/api/"),
     },
-    "log": {
-        "view": Uri("/mini_buildd/log/", auth=AUTH_STAFF, django_with_path=True),
-        "static": Uri("/static/log/", auth=AUTH_STAFF, with_index=True),
-    },
     "admin": {
         "view": Uri("/admin/"),
     },
@@ -219,6 +197,7 @@ class Routes(dict):
         # 'var/shared': Shared with chroots
         self._add("builds", files.Path(homepth("var/shared/builds"), create=True))   # Build directory
         self._add("libdir", files.Path(homepth("var/shared/libdir"), create=True))   # Shared libdir: Can optionally be used for persistent shared data (like ccache)
+        self._add("debug", files.Path(homepth("var/shared/debug"), create=True))     # Shared directory for optional manual (sbuild) debugging
 
         self._add("events", files.Path(homepth("var/events"), create=True))
         self._add("event_hooks", files.Path(homepth("etc/event-hooks"), create=True))
@@ -255,3 +234,19 @@ def default_ftp_endpoint():
 
 def default_identity():
     return HOSTNAME
+
+
+def default_email_address():
+    return f"mini-buildd@{HOSTNAME_FQDN}"
+
+
+def default_allow_emails_to():
+    return f".*@{HOSTNAME_FQDN}"
+
+
+class SqlitePath():
+    def __init__(self):
+        self.path = ROUTES["home"].path.join("config.sqlite")
+
+    def fix_perms(self):
+        os.chmod(self.path, stat.S_IRUSR | stat.S_IWUSR | stat.S_IRGRP)
