@@ -29,8 +29,11 @@ class DebianPackageTracker():
             for d in version_tags:
                 codename = d['title'].split("(")[1].split(" ")[0].translate({ord(")"): None})
                 version = d.find_next_sibling("a").get_text("", strip=True)
-                self.info[codename] = {"version": version,
-                                       "changelog_url": f"{tracker_url}/media/packages/{src_package[:4] if src_package.startswith('lib') else src_package[0]}/{src_package}/changelog-{version}"}
+                version_url = version.replace("~", "").replace("+", "")
+                self.info[codename] = {
+                    "version": version,
+                    "changelog_url": f"{tracker_url}/media/packages/{src_package[:4] if src_package.startswith('lib') else src_package[0]}/{src_package}/changelog-{version_url}"
+                }
 
     def get_info(self, codename):
         return self.info[codename]
