@@ -1,9 +1,9 @@
-import threading
 import logging
+import threading
 
 import django.conf
 
-from mini_buildd import config, util, gnupg, threads, ftpd, packager, builder, events, cron, api, models
+from mini_buildd import api, builder, config, cron, events, ftpd, gnupg, models, packager, threads, util, values
 
 LOG = logging.getLogger(__name__)
 
@@ -17,7 +17,7 @@ class RemotesKeyring(gnupg.TmpGnuPG):
             self.add_pub_key(util.daemon().gnupg.pub_key)
         for r in models.Remote.mbd_get_active_or_auto_reactivate():
             self.add_pub_key(r.key)
-            LOG.debug(f"Remote key added for '{r}': {r.key_long_id}: {r.key_name}")
+            LOG.debug("Remote key added for '%s': %s: %s", r, r.key_long_id, r.key_name)
 
 
 class UploadersKeyring(gnupg.TmpGnuPG):
@@ -28,22 +28,22 @@ class UploadersKeyring(gnupg.TmpGnuPG):
         r = models.Repository.objects.get(pk=repo_identity)
         # Add keys from django users
         for u in django.contrib.auth.models.User.objects.filter(is_active=True):
-            LOG.debug(f"Checking user: {u}")
+            LOG.debug("Checking user: %s", u)
             uploader = None
             try:
                 uploader = u.uploader
             except BaseException as e:
-                LOG.warning(f"User '{u}' does not have an uploader profile (deliberately removed?): {e}")
+                LOG.warning("User '%s' does not have an uploader profile (deliberately removed?): %s", u, e)
 
             if uploader and uploader.mbd_is_active() and uploader.may_upload_to.all().filter(identity=repo_identity):
-                LOG.debug(f"Adding uploader key for '{repo_identity}': {uploader.key_long_id}: {uploader.key_name}")
+                LOG.debug("Adding uploader key for '%s': %s: %s", repo_identity, uploader.key_long_id, uploader.key_name)
                 self.add_pub_key(uploader.key)
 
         # Add configured extra keyrings
         for line in r.extra_uploader_keyrings.splitlines():
             line = line.strip()
             if line and line[0] != "#":
-                LOG.debug(f"Adding keyring: {line}")
+                LOG.debug("Adding keyring: %s", line)
                 self.add_keyring(line)
 
         # Always add our key too for internal builds
@@ -60,13 +60,13 @@ class Daemon(threads.EventThread, metaclass=util.Singleton):
         return models.get_daemon()
 
     def __init__(self):
-        self.builder = builder.Builder(max_parallel_builds=self.model.build_queue_size)
+        self.builder = builder.Builder(max_parallel_builds=self.model.max_parallel_builds)
         self.packager = packager.Packager()
         self.ftpd = ftpd.FtpD(endpoint=self.model.mbd_get_ftp_endpoint())
         self.crontab = cron.Tab()
         super().__init__(subthreads=[self.ftpd, self.packager, self.builder, self.crontab], name=str(self.model))
 
-        self.events = events.Queue.load(maxlen=self.model.show_last_packages)
+        self.events = events.Queue.load(maxlen=self.model.event_queue_size)
         self.gnupg = self.model.mbd_gnupg()
         self.public_key_cache = gnupg.PublicKeyCache()
 
@@ -96,6 +96,7 @@ class Daemon(threads.EventThread, metaclass=util.Singleton):
             if not self.model.mbd_is_active():
                 raise util.HTTPUnavailable("Can't start: Daemon instance is deactivated")
             if not self.is_alive():
+                values.cache_clear()
                 self.ftpd.bind(self.model.ftpd_options)
                 self.start()
 
@@ -105,6 +106,7 @@ class Daemon(threads.EventThread, metaclass=util.Singleton):
                 self.shutdown()
                 self.join()
                 self.public_key_cache.close()
+                values.cache_clear()
                 Daemon.destroy()
 
     def mbd_inspect(self):
