@@ -1,17 +1,62 @@
-"""Run reprepro commands."""
+"""
+Run reprepro commands
 
+.. error:: **reprepro** (bookworm): Sometimes hangs on keyring package in testsuite (blocking all) (:debbug:`1056380`)
+
+  Reproduce: ``./devel profile _all updatetestall``.
+
+  This was introduced with the fix for (:debbug:`1050321`) in ``5.3.1-1+deb12u1``. Unfortunately, this
+  version is still [Apr 2024] in stable/bookworm. Fixed for trixie+.
+
+.. attention:: **reprepro**: Fails with ``debian/`` being a symlink in Debian native packages (:debbug:`768046`)
+
+  In such a case, builds will be fine, but reprepro will not be able to install the package; you will only be able to
+  see reprepro's error "No section and no priority for" in the ``daemon.log``.
+
+  For the moment, just avoid such a setup (which is imho not desirable anyway). However, as it's a legal setup afaik it
+  should work after all.
+
+.. attention:: **reprepro**: Don't switch to ``reprepro 5.4`` yet (:debbug:`1017983`)
+
+  As of *June 2023* ``5.4.2``, this is still in experimental.
+
+  There are still db migration problems to be fixed. Furthermore, I regularly experience lockups in full testsuite runs.
+
+.. attention:: **reprepro** (``dist.py`` setup workaround): Can't handle Ubuntu's ``ddeb`` (:debbug:`730572`)
+
+.. note:: **reprepro**: Multiple versions of packages in one distribution
+
+  This is not really a problem, but a uncommon situation that may lead to confusion.
+
+  Generally, reprepro does allow exactly only one version of a package in a distribution; the only exception is when
+  installed in *different components* (f.e., ``main`` vs. ``non-free``).
+
+  This usually happens when the 'Section' changes in the corresponding 'debian/control' file of the source package, or if
+  packages were installed manually using "-C" with reprepro.
+
+  Check with the "ls" command if this is the case, i.e., s.th. like:
+
+  .. code:: bash
+
+    mini-buildd-api ls ENDPOINT my-package
+
+  you may see multiple entries for one distribution with different components.
+
+  mini-buildd handles this gracefully; the :apicall:`remove`, the :apicall:`migrate` and the :apicall:`port` all include
+  an optional 'version' parameter to be able to select a specific version.
+
+  In the automated rollback handling, all versions of a source package are shifted.
+"""
+
+import glob
+import logging
 import os
 import shutil
 import threading
-import glob
-
-import logging
 
 import debian.debian_support
 
-import mini_buildd.dist
-import mini_buildd.call
-import mini_buildd.events
+from mini_buildd import call, changes, config, dist, util
 
 LOG = logging.getLogger(__name__)
 
@@ -45,17 +90,17 @@ class Ls(dict):
             if item:
                 # reprepro lsbycomponent format: "<source> | <version> | <distribution> | <component> | <architecture>"
                 split = item.split("|")
-                dist = mini_buildd.dist.Dist(split[2].strip())
+                _dist = dist.Dist(split[2].strip())
                 values = {
                     "version": split[1].strip(),
                     "component": split[3].strip(),
                     "architecture": split[4].strip(),
                 }
-                if (codenames is None or dist.codename in codenames) and (not version or values["version"] == version) and (not min_version or debian.debian_support.Version(values["version"]) >= debian.debian_support.Version(min_version)):
-                    self.codenames.add(mini_buildd.dist.Codename(dist.codename))
-                    save_to = self.setdefault(dist.get(rollback=False), {"rollbacks": {}})
-                    if dist.is_rollback:
-                        save_to["rollbacks"][dist.get()] = values
+                if (codenames is None or _dist.codename in codenames) and (not version or values["version"] == version) and (not min_version or debian.debian_support.Version(values["version"]) >= debian.debian_support.Version(min_version)):
+                    self.codenames.add(dist.Codename(_dist.codename))
+                    save_to = self.setdefault(_dist.get(rollback=False), {"rollbacks": {}})
+                    if _dist.is_rollback:
+                        save_to["rollbacks"][_dist.get()] = values
                     else:
                         # Need to set individual items here to not possibly overwrite 'rollback'
                         for k, v in values.items():
@@ -67,13 +112,13 @@ class Ls(dict):
         for diststr in self:
             ls = self[diststr]
 
-            repository, distribution, suite = mini_buildd.mdls().repository.parse_diststr(diststr)
+            repository, distribution, suite = util.models().parse_diststr(diststr)
 
             if ls.get("version") is not None:
                 ls["dsc_path"] = repository.mbd_dsc_pool_path(self.source, ls["version"], raise_exception=False)
 
                 # Add changes files for convenience only - you can get to the changes files via 'events for this version' link
-                events_path = mini_buildd.config.ROUTES["events"].path
+                events_path = config.ROUTES["events"].path
                 ls["changes_paths"] = [events_path.removeprefix(p) for p in glob.glob(events_path.join(self.source, ls.get("version"), "**", "*_source.changes"), recursive=True)]
 
             ls["uploadable"] = suite.uploadable
@@ -88,11 +133,12 @@ class Ls(dict):
                 if rollback_ls.get("version") is not None:
                     rollback_ls["dsc_path"] = repository.mbd_dsc_pool_path(self.source, rollback_ls["version"], raise_exception=False)
 
-    def rollbacks(self):
+    def rollbacks(self, diststr=None):
         result = {}
-        for _v in self.values():
-            for d, v in _v["rollbacks"].items():
-                result[d] = v
+        for _d, _v in self.items():
+            if diststr is None or _d == diststr:
+                for d, v in _v["rollbacks"].items():
+                    result[d] = v
         return result
 
     def filter(self, ls=None, diststr=None, version=None, raise_if_found="", raise_if_not_found=""):
@@ -104,25 +150,25 @@ class Ls(dict):
             if ls_values.get("version") is not None and (diststr is None or ls_diststr == diststr) and (version is None or ls_values.get("version") == version):
                 result[ls_diststr] = ls_values
         if result and raise_if_found:
-            raise mini_buildd.HTTPBadRequest(f"{raise_if_found}: Source '{self.source}_{version or 'any'}' found in '{diststr or 'any'}' distribution")
+            raise util.HTTPBadRequest(f"{raise_if_found}: Source '{self.source}_{version or 'any'}' found in '{diststr or 'any'}' distribution")
         if not result and raise_if_not_found:
-            raise mini_buildd.HTTPBadRequest(f"{raise_if_not_found}: Source '{self.source}_{version or 'any'}' not found in '{diststr or 'any'}' distribution")
+            raise util.HTTPBadRequest(f"{raise_if_not_found}: Source '{self.source}_{version or 'any'}' not found in '{diststr or 'any'}' distribution")
         return result
 
-    def filter_rollbacks(self, **kwargs):
-        return self.filter(self.rollbacks(), **kwargs)
+    def filter_rollbacks(self, diststr=None, **kwargs):
+        return self.filter(self.rollbacks(diststr), **kwargs)
 
     def filter_all(self, **kwargs):
         return self.filter({**self, **self.rollbacks()}, **kwargs)
 
-    def changes(self, diststr, version, **kwargs):
-        values = self.filter(diststr=diststr, version=version, raise_if_not_found="Internal")[diststr]
-        return mini_buildd.changes.Changes({"Distribution": diststr, "Source": self.source, "Version": values["version"], "Architecture": "source", "Component": values["component"]}, **kwargs)
+    def changes(self, diststr, version, ls=None, **kwargs):
+        values = self.filter(ls=ls, diststr=diststr, version=version, raise_if_not_found="Internal")[diststr]
+        return changes.Changes({"Distribution": diststr, "Source": self.source, "Version": values["version"], "Architecture": "source", "Component": values["component"]}, **kwargs)
 
 
 class Reprepro():
     r"""
-    Abstraction to reprepro repository commands.
+    Abstraction to reprepro repository commands
 
     *Locking*
 
@@ -166,7 +212,7 @@ class Reprepro():
         return f"Reprepro repository at {self._basedir}"
 
     def _call(self, args):
-        return mini_buildd.call.Call(self._cmd + args).check().log().stdout
+        return call.Call(self._cmd + args).check().log().stdout
 
     def _call_locked(self, args):
         with self._lock:
@@ -174,11 +220,11 @@ class Reprepro():
 
     @classmethod
     def clean_exportable_indices(cls, dist_dir):
-        LOG.info(f"Reprepro: Cleaning exportable indices from {dist_dir}...")
+        LOG.info("Reprepro: Cleaning exportable indices from %s...", dist_dir)
         for item in os.listdir(dist_dir):
             if item != "snapshots":
                 rm_path = os.path.join(dist_dir, item)
-                LOG.debug(f"PURGING: {rm_path}")
+                LOG.debug("PURGING: %s", rm_path)
                 if os.path.isdir(rm_path) and not os.path.islink(rm_path):
                     shutil.rmtree(rm_path, ignore_errors=True)
                 else:
@@ -186,7 +232,7 @@ class Reprepro():
 
     def reindex(self, distributions):
         """
-        (Re-)index repository.
+        (Re-)index repository
 
         Remove all files from repository that can be re-indexed via
         "reprepro export", and remove all files that would not (i.e.,
@@ -201,7 +247,7 @@ class Reprepro():
         manual.
 
         """
-        LOG.info(f"(Re)indexing {self}")
+        LOG.info("(Re)indexing %s", self)
         with self._lock:
             dists_dir = os.path.join(self._basedir, "dists")
             os.makedirs(dists_dir, exist_ok=True)
@@ -210,12 +256,12 @@ class Reprepro():
                 dist_dir = os.path.join(dists_dir, dist_str)
                 self.clean_exportable_indices(dist_dir)
 
-                dist = mini_buildd.dist.Dist(dist_str)
-                if dist.get(rollback=False) not in distributions:
-                    LOG.debug(f"Dist has been removed from repo: {dist_dir}")
+                _dist = dist.Dist(dist_str)
+                if _dist.get(rollback=False) not in distributions:
+                    LOG.debug("Dist has been removed from repo: %s", dist_dir)
                     for s in self.get_snapshots(dist_str):
                         self._del_snapshot(dist_str, s)  # Call w/o locking!
-                    LOG.debug(f"PURGING: {dist_dir}")
+                    LOG.debug("PURGING: %s", dist_dir)
                     shutil.rmtree(dist_dir, ignore_errors=True)
 
             # Update reprepro dbs, and delete any packages no longer in dists.
@@ -236,8 +282,8 @@ class Reprepro():
     def remove(self, package, distribution, version=None):
         return self._call_locked(["removesrc", distribution, package] + ([version] if version else []))
 
-    def install(self, changes, distribution):
-        return self._call_locked(["include", distribution, changes])
+    def install(self, _changes, distribution):
+        return self._call_locked(["include", distribution, _changes])
 
     def install_dsc(self, dsc, distribution):
         return self._call_locked(["includedsc", distribution, dsc])
@@ -247,13 +293,13 @@ class Reprepro():
     #
     def snapshots_dir(self, distribution):
         if not distribution:
-            raise mini_buildd.HTTPBadRequest("Empty reprepro snapshots distribution name")
+            raise util.HTTPBadRequest("Empty reprepro snapshots distribution name")
         return os.path.join(self._basedir, "dists", distribution, "snapshots")
 
     def snapshot_dir(self, distribution, name):
         sd = self.snapshots_dir(distribution)
         if not name:
-            raise mini_buildd.HTTPBadRequest("Empty reprepro snapshot name")
+            raise util.HTTPBadRequest("Empty reprepro snapshot name")
         return os.path.join(sd, name)
 
     def get_snapshots(self, distribution, prefix=""):
@@ -263,7 +309,7 @@ class Reprepro():
     def gen_snapshot(self, distribution, name):
         sd = self.snapshot_dir(distribution, name)
         if os.path.exists(sd):
-            raise mini_buildd.HTTPBadRequest(f"Reprepro snapshot '{name}' for '{distribution}' already exists")
+            raise util.HTTPBadRequest(f"Reprepro snapshot '{name}' for '{distribution}' already exists")
 
         with self._lock:
             self._call(["gensnapshot", distribution, name])
@@ -271,12 +317,13 @@ class Reprepro():
     def _del_snapshot(self, distribution, name):
         sd = self.snapshot_dir(distribution, name)
         if not os.path.exists(sd):
-            raise mini_buildd.HTTPBadRequest(f"Reprepro snapshot '{name}' for '{distribution}' does not exist")
+            raise util.HTTPBadRequest(f"Reprepro snapshot '{name}' for '{distribution}' does not exist")
 
-        LOG.info(f"Deleting reprepro snapshot '{sd}'...")
+        LOG.info("Deleting reprepro snapshot '%s'...", sd)
         self._call(["unreferencesnapshot", distribution, name])
-        shutil.rmtree(sd, ignore_errors=True)
+        self._call(["--delete", "clearvanished"])
         self._call(["deleteunreferenced"])
+        shutil.rmtree(sd, ignore_errors=True)
 
     def del_snapshot(self, distribution, name):
         with self._lock:
